"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const util_1 = require("util");
const redis_1 = __importDefault(require("redis"));
const redis_commands_1 = require("redis-commands");
const client_1 = __importDefault(require("@blued-core/client"));
class RedisClient extends client_1.default {
    buildClient(key) {
        const { host, port } = this.conf.get(key);
        // 增加回调方法
        let cb = () => { };
        if (this.option.cb && typeof this.option.cb === 'function') {
            ({ cb } = this.option);
        }
        const client = createRedisClient(host, Number(port), cb);
        return {
            client,
            clean() {
                client.quit();
            },
        };
    }
}
exports.default = RedisClient;
/**
 * 创建redis客户端连接
 * @param {string} host redis对应的IP
 * @param {number} port 创建链接的端口
 * @return {RedisClient}
 */
function createRedisClient(host, port = 6379, cb) {
    const redisClient = redis_1.default.createClient(port, host);
    // build promisify methods
    const redisPromisifyClient = build(redisClient, cb);
    return redisPromisifyClient;
}
/**
 * 将 Redis 命令转换为 Promise 版本
 * @param {any} target RedisClient
 * @return {any}
 */
function build(target, cb) {
    redis_commands_1.list.forEach((method) => {
        const func = target[method];
        if (typeof func === 'function') {
            const promisifyFn = util_1.promisify(func).bind(target);
            if (['multi'].includes(method)) {
                target[method] = recordMultiDecorator(func.bind(target), cb);
                target[method.toUpperCase()] = recordMultiDecorator(func.bind(target), cb);
            }
            else if (['info', 'quit'].includes(method)) {
                target[method] = promisifyFn;
                target[method.toUpperCase()] = promisifyFn;
            }
            else {
                target[method] = recordDecorator(promisifyFn, cb);
                target[method.toUpperCase()] = recordDecorator(promisifyFn, cb);
            }
        }
    });
    return target;
}
/**
 * 使用高阶函数装饰函数
 * @param {function} 原函数
 * @returns {any}
 */
function recordDecorator(wrapped, cb) {
    return async (...args) => {
        const name = wrapped.name.replace('bound ', '');
        const result = await wrapped(...args);
        cb(name, args, result);
        return result;
    };
}
function recordMultiDecorator(wrapped, cb) {
    return (...args) => {
        const name = wrapped.name.replace('bound ', '');
        cb(name, args);
        return wrapped(...args);
    };
}
//# sourceMappingURL=index.js.map